@@ -16,11 +16,11 @@ Net::Rest::Generic - A tool for generically interacting with restfull (or restli
 
 =head1 VERSION
 
-Version 0.01
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 SYNOPSIS
 
@@ -28,19 +28,19 @@ Net::Rest::Generic is a module for interacting with arbitrary HTTP/S APIs.
 It attempts to do this by providing an easy to read syntax for generating the request
 URLs on the fly, and generally Doing The Right Thing.
 
-Perhaps a little code snippet.
+A basic example:
 
     use Net::Rest::Generic;
 
     my $api = Net::Rest::Generic->new(
-                host => "api.foo.com",
-                scheme => "https",
-                base => "api/v1",
-                authorization_basic => {
-                        username => "user",
-                        password => "password",
-                }
-        );
+		host => "api.foo.com",
+		scheme => "https",
+		base => "api/v1",
+		authorization_basic => {
+			username => "user",
+			password => "password",
+		}
+	);
     my $result = $api->setRequestMethod("POST")->this->is->the->url("parameterized")->addLabel("new");
 
     my $details = $api->setRequestMethod("GET")->user("superUser")->details->color->favorite;
@@ -70,12 +70,28 @@ sub new {
 	while (my ($k, $v) = each %defaults) {
 		$self->{$k} ||= $v;
 	}
-	my $input = Net::Rest::Generic::Utility::_validateInput($self);
+
+	my $input;
+	my @modes = qw(delete get post put head);
+	if (! grep (/$self->{mode}/i, @modes)) {
+		$input = Net::Rest::Generic::Error->throw(
+			category => 'input',
+			message => 'mode must be one of the following: ' . join(', ', @modes) . '. You supplied: ' . $self->{mode},
+		);
+	}
+	my @schemes = qw(http https);
+	if (! grep (/$self->{scheme}/i, @schemes)) {
+		$input = Net::Rest::Generic::Error->throw(
+			category => 'input',
+			message  => 'scheme must be one of the following: ' . join(', ', @schemes) . '. You supplied: ' . $self->{scheme},
+		);
+	}
 	return $input if (ref($input) eq 'Net::Rest::Generic::Error');
-        $self->{uri} = URI->new();
-        $self->{uri}->scheme($self->{scheme});
-        $self->{uri}->host($self->{host});
-        $self->{uri}->port($self->{port}) if exists $self->{port};
+
+	$self->{uri} = URI->new();
+	$self->{uri}->scheme($self->{scheme});
+	$self->{uri}->host($self->{host});
+	$self->{uri}->port($self->{port}) if exists $self->{port};
 	return bless $self, $class;
 }
 
@@ -87,21 +103,21 @@ sub AUTOLOAD {
 	return if ($key eq 'DESTROY');
 
 	push @{ $self->{chain} }, $key;
-        my $args;
-        if (ref($_[0])) {
-                $args = $_[0];
-        }
-        else {
-                push @{ $self->{chain} }, @_;
-        }
+	my $args;
+	if (ref($_[0])) {
+		$args = $_[0];
+	}
+	else {
+		push @{ $self->{chain} }, @_;
+	}
 	if (want('OBJECT') || want('VOID')) {
 		return $self;
 	}
 
-        unshift(@{ $self->{chain} }, $self->{base}) if exists $self->{base};
+	unshift(@{ $self->{chain} }, $self->{base}) if exists $self->{base};
 	my $url = join('/', @{ $self->{chain} });
-        $self->{chain} = [];
-        $self->{uri}->path($url);
+	$self->{chain} = [];
+	$self->{uri}->path($url);
 
 	if ($self->{string}) {
 		if (want('LIST')) {
@@ -112,7 +128,7 @@ sub AUTOLOAD {
 		}
 	}
 
-        return Net::Rest::Generic::Utility::_doRestCall($self, $self->{mode}, $self->{uri}, $args);
+	return Net::Rest::Generic::Utility::_doRestCall($self, $self->{mode}, $self->{uri}, $args);
 }
 
 =head2 addLabel()
@@ -126,9 +142,9 @@ usage: $api->addLabel("new");
 =cut
 
 sub addLabel {
-        my ($self, @labels) = @_;
-        push @{$self->{chain}}, @labels;
-        return $self;
+	my ($self, @labels) = @_;
+	push @{$self->{chain}}, @labels;
+	return $self;
 }
 
 =head2 setRequestMethod()
@@ -141,16 +157,15 @@ usage $api->setRequestMethod("POST")->......
 =cut
 
 sub setRequestMethod {
-        my ($self, $method) = @_;
-        $self->{mode} = $method;
-        return $self;
+	my ($self, $method) = @_;
+	$self->{mode} = $method;
+	return $self;
 }
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Sebastian Green-Husted C<< <ricecake at tfm.nu> >>
-
-Shane Utt C<< <shaneutt at linux.com> >>
+Sebastian Green-Husted, C<< <ricecake at tfm.nu> >>
+Shane Utt, C<< <shaneutt at linux.com> >>
 
 =head1 BUGS
 
@@ -186,13 +201,10 @@ L<http://search.cpan.org/dist/Net-Rest-Generic/>
 
 =back
 
-
-=head1 ACKNOWLEDGEMENTS
-
-
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2013 Sebastian Green-Husted,Shane Utt.
+Copyright (C) 2013 Sebastian Green-Husted, All Rights Reserved.
+Copyright (C) 2013 Shane Utt, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
